@@ -8,7 +8,7 @@ use Locale::TextDomain::OO;
 our $VERSION = 0;
 
 my $loc = Locale::TextDomain::OO->new(
-    plugins => [ qw( Expand::Gettext::Loc Expand::BabelFish::Loc ) ],
+    plugins => [ qw( Expand::Gettext::Loc ) ],
 );
 
 # run all translations
@@ -78,15 +78,6 @@ my $loc = Locale::TextDomain::OO->new(
         2,
         num => 2,
     ),
-    $loc->loc_b(
-        'date',
-        foo => 'bar',
-    ),
-    $loc->loc_bp(
-        'appointment',
-        'date',
-        foo => 'bar',
-    ),
 ;
 
 # Extract special stuff only
