@@ -6,7 +6,7 @@ use Moo;
 use MooX::Types::MooseLike::Base qw(ArrayRef Str);
 use namespace::autoclean;
 
-our $VERSION = '2.007';
+our $VERSION = '2.010';
 
 extends qw(
     Locale::TextDomain::OO::Extract::Base::RegexBasedExtractor
@@ -15,18 +15,43 @@ with qw(
     Locale::TextDomain::OO::Extract::Role::File
 );
 
-my $text_rule = qr{ \s* ( [^<]+ ) }xms;
+has filter => (
+    is      => 'rw',
+    isa     => ArrayRef[Str],
+    lazy    => 1,
+    default => sub {[ 'all' ]},
+);
+
+sub _filtered_start_rule {
+    my $self = shift;
+
+    my %filter_of = map { $_ => 1 } @{ $self->filter };
+    my $list_if = sub {
+        my ( $key, @list ) = @_;
+        my $condition
+            = $filter_of{all} && ! $filter_of{"!$key"}
+            || $filter_of{$key};
+        return $condition ? @list : ();
+    };
+    my $with_bracket = join "\n| ", (
+        $list_if->('Gettext',      qr{ ["] [^"]*? \b __   \b [^"]*? ["] }xms,
+                                   qr{ ['] [^']*? \b __   \b [^']*? ['] }xms),
+        $list_if->('Gettext::Loc', qr{ ["] [^"]*? \b loc_ \b [^"]*? ["] }xms,
+                                   qr{ ['] [^']*? \b loc_ \b [^']*? ['] }xms),
+        $list_if->('Maketext',     qr{ ["] [^"]*? \b loc  \b [^"]*? ["] }xms,
+                                   qr{ ['] [^']*? \b loc  \b [^']*? ['] }xms),
+    );
+    $with_bracket ||= '(?!)';
+
+    return qr{
+        [<] [^>]*?
+        \b class \s* [=] \s*
+        (?: $with_bracket )
+    }xms;
+}
 
 ## no critic (ComplexRegexes)
-my $start_rule = qr{
-    [<] [^>]*?
-    \b class \s* [=] \s*
-    (?:
-        ["] [^"]*? \b (?: loc_ | __ | loc ) \b [^"]*? ["]
-        |
-        ['] [^']*? \b (?: loc_ | __ | loc ) \b [^']*? [']
-    )
-}xms;
+my $text_rule = qr{ \s* ( [^<]+ ) }xms;
 
 my $rules = [
     # <input class="... loc_|__|loc ..." ... placeholder="text to extract" ... />
@@ -295,7 +320,7 @@ sub stack_item_mapping {
 sub extract {
     my $self = shift;
 
-    $self->start_rule($start_rule);
+    $self->start_rule( $self->_filtered_start_rule );
     $self->rules($rules);
     $self->preprocess;
     $self->SUPER::extract;
@@ -322,7 +347,7 @@ $HeadURL: svn+ssh://steffenw@svn.code.sf.net/p/perl-gettext-oo/code/extract/trun
 
 =head1 VERSION
 
-2.007
+2.010
 
 =head1 DESCRIPTION
 
@@ -352,7 +377,16 @@ Whitespace is allowed everywhere.
     use Locale::TextDomain::OO::Extract::HTML;
     use Path::Tiny qw(path);
 
-    my $extractor = Locale::TextDomain::OO::Extract::HTML->new;
+    my $extractor = Locale::TextDomain::OO::Extract::HTML->new(
+        # optional filter parameter, the default is ['all'],
+        # the following means:
+        # extract for all plugins but not for Plugin
+        # Locale::TextDomain::OO::Plugin::Maketext
+        filter => [ qw(
+            all
+            !Maketext
+        ) ],
+    );
     for ( @files ) {
         $extractor->clear;
         $extractor->filename($_);            # dir/filename for reference
@@ -372,6 +406,15 @@ See Locale::TextDomain::OO::Extract to replace the defaults.
 
     my $extractor = Locale::TextDomain::OO::Extract::HTML->new;
 
+=head2 method filter
+
+Ignore some of 'all' or define what to scan.
+See SYNOPSIS and DESCRIPTION for how and what.
+
+    my $array_ref = $extractor->filter;
+
+    $extractor->filter(['all']); # the default
+
 =head2 method preprocess (called by method extract)
 
 Remove code between <!-- -->
