@@ -6,7 +6,7 @@ use Moo;
 use MooX::Types::MooseLike::Base qw(ArrayRef Str);
 use namespace::autoclean;
 
-our $VERSION = '2.007';
+our $VERSION = '2.010';
 
 extends qw(
     Locale::TextDomain::OO::Extract::Base::RegexBasedExtractor
@@ -15,6 +15,42 @@ with qw(
     Locale::TextDomain::OO::Extract::Role::File
 );
 
+has filter => (
+    is      => 'rw',
+    isa     => ArrayRef[Str],
+    lazy    => 1,
+    default => sub {[ 'all' ]},
+);
+
+sub _filtered_start_rule {
+    my $self = shift;
+
+    my %filter_of = map { $_ => 1 } @{ $self->filter };
+    my $list_if = sub {
+        my ( $key, @list ) = @_;
+        my $condition
+            = $filter_of{all} && ! $filter_of{"!$key"}
+            || ! $filter_of{'!all'} && $filter_of{$key};
+        return $condition ? @list : ();
+    };
+    my $with_bracket = join "\n| ", (
+        $list_if->('Gettext',                           '__? n? p? x?',
+                                                        'n? p? gettext'),
+        $list_if->('Gettext::DomainAndCategory',        '__? d? c? n? p? x?',
+                                                        'd? c? n? p? gettext'),
+        $list_if->('Gettext::Loc',                      'loc_ n? p? x?'),
+        $list_if->('Gettext::Loc::DomainAndCategory',   'loc_ d? c? n? p? x?'),
+        $list_if->('BabelFish::Loc',                    'loc_b p?'),
+        $list_if->('BabelFish::Loc::DomainAndCategory', 'loc_b d? c? p?'),
+    );
+    $with_bracket ||= '(?!)';
+
+    return qr{
+        \b N?
+        (?: $with_bracket ) \s* [(]
+    }xms;
+}
+
 my $category_rule
     = my $context_rule
     = my $domain_rule
@@ -50,17 +86,6 @@ my $comma_rule = qr{ \s* [,] }xms;
 my $count_rule = qr{ \s* ( [^,)]+ ) }xms;
 my $close_rule = qr{ \s* [,]? \s* ( [^)]* ) [)] }xms;
 
-my $start_rule = qr{
-    \b N?
-    (?:
-        # Gettext::Loc, Gettext
-        (?: loc_ | __? ) d? c? n? p? x?
-        # Gettext
-        | d? c? n? p? gettext
-    )
-    \s* [(]
-}xms;
-
 my $rules = [
     # loc_, _, __
     [
@@ -389,7 +414,7 @@ my $rules = [
         'end',
     ],
 
-    # babelfish loc_b
+    # loc_b... (BabelFish)
     'or',
     [
         'begin',
@@ -855,7 +880,7 @@ sub stack_item_mapping {
 sub extract {
     my $self = shift;
 
-    $self->start_rule($start_rule);
+    $self->start_rule( $self->_filtered_start_rule );
     $self->rules($rules);
     $self->preprocess;
     $self->SUPER::extract;
@@ -882,7 +907,7 @@ $HeadURL: svn+ssh://steffenw@svn.code.sf.net/p/perl-gettext-oo/code/extract/trun
 
 =head1 VERSION
 
-2.007
+2.010
 
 =head1 DESCRIPTION
 
@@ -890,6 +915,7 @@ This module extracts internationalization data from JavaScript code.
 
 Implemented Rules:
 
+ # Gettext::Loc
  loc_('...
  loc_x('...
  loc_n('...
@@ -899,6 +925,7 @@ Implemented Rules:
  loc_np('...
  loc_npx('...
 
+ # Gettext::Loc::DomainAndCategory
  loc_d('...
  loc_dx('...
  loc_dn('...
@@ -926,6 +953,21 @@ Implemented Rules:
  loc_dcnp('...
  loc_dcnpx('...
 
+ # BabelFish::Loc
+ loc_b('...
+ loc_bp('...
+
+ # BabelFish::Loc::DomainAndCategory
+ loc_bd('...
+ loc_bdp('...
+
+ loc_bc('...
+ loc_bcp('...
+
+ loc_bdc('...
+ loc_bdcp('...
+
+ # Gettext
  _('...
  _x('...
  _n('...
@@ -935,6 +977,21 @@ Implemented Rules:
  _np('...
  _npx('...
 
+ __('...
+ __x('...
+ __n('...
+ __nx('...
+ __p('...
+ __px('...
+ __np('...
+ __npx('...
+
+ gettext('...
+ ngettext('...
+ pgettext('...
+ npgettext('...
+
+ # Gettext::DomainAndCategory
  _d('...
  _dx('...
  _dn('...
@@ -962,15 +1019,6 @@ Implemented Rules:
  _dcnp('...
  _dcnpx('...
 
- __('...
- __x('...
- __n('...
- __nx('...
- __p('...
- __px('...
- __np('...
- __npx('...
-
  __d('...
  __dx('...
  __dn('...
@@ -998,14 +1046,6 @@ Implemented Rules:
  __dcnp('...
  __dcnpx('...
 
- loc_b('...
- loc_bp('...
-
- gettext('...
- ngettext('...
- pgettext('...
- npgettext('...
-
  dgettext('...
  dngettext('...
  dpgettext('...
@@ -1030,7 +1070,13 @@ Also possible all functions with N in front like Nloc_, N__, Ngettext, ... to pr
     use Locale::TextDomain::OO::Extract::JavaScript;
     use Path::Tiny qw(path);
 
-    my $extractor = Locale::TextDomain::OO::Extract::JavaScript->new;
+    my $extractor = Locale::TextDomain::OO::Extract::JavaScript->new(
+        # optional filter parameter, the default is ['all'],
+        # the following means:
+        # extract for all plugins but not for Plugin
+        # Locale::TextDomain::OO::Plugin::BabelFish::Loc
+        filter => [ qw( all !BabelFish::Loc ) ],
+    );
     for ( @files ) {
         $extractor->clear;
         $extractor->filename($_);            # dir/filename for reference
@@ -1050,6 +1096,15 @@ See Locale::TextDomain::OO::Extract to replace the defaults.
 
     my $extractor = Locale::TextDomain::OO::Extract::JavaScript->new;
 
+=head2 method filter
+
+Ignore some of 'all' or define what to scan.
+See SYNOPSIS and DESCRIPTION for how and what.
+
+    my $array_ref = $extractor->filter;
+
+    $extractor->filter(['all']); # the default
+
 =head2 method preprocess (called by method extract)
 
 This method removes all comments.
