@@ -7,7 +7,7 @@ use Moo;
 use MooX::Types::MooseLike::Base qw(ArrayRef Str);
 use namespace::autoclean;
 
-our $VERSION = '2.007';
+our $VERSION = '2.010';
 
 extends qw(
     Locale::TextDomain::OO::Extract::Base::RegexBasedExtractor
@@ -16,6 +16,41 @@ with qw(
     Locale::TextDomain::OO::Extract::Role::File
 );
 
+has filter => (
+    is      => 'rw',
+    isa     => ArrayRef[Str],
+    lazy    => 1,
+    default => sub {[ 'all' ]},
+);
+
+sub _filtered_start_rule {
+    my $self = shift;
+
+    my %filter_of = map { $_ => 1 } @{ $self->filter };
+    my $list_if = sub {
+        my ( $key, @list ) = @_;
+        my $condition
+            = $filter_of{all} && ! $filter_of{"!$key"}
+            || $filter_of{$key};
+        return $condition ? @list : ();
+    };
+    my $with_bracket = join "\n| ", (
+        $list_if->('Gettext',                           'N? __ n? p? x?'),
+        $list_if->('Gettext::DomainAndCategory',        'N? __ d? c? n? p? x?'),
+        $list_if->('Gettext::Loc',                      'N? loc_ n? p? x?'),
+        $list_if->('Gettext::Loc::DomainAndCategory',   'N? loc_ d? c? n? p? x?'),
+        $list_if->('BabelFish::Loc',                    'N? loc_b p?'),
+        $list_if->('BabelFish::Loc::DomainAndCategory', 'N? loc_b d? c? p?'),
+        $list_if->('Maketext',                          'l'),
+    );
+    $with_bracket ||= '(?!)';
+
+    return qr{
+        \b
+        (?: $with_bracket ) \s* [(]
+    }xms;
+}
+
 my $category_rule
     = my $context_rule
     = my $domain_rule
@@ -69,20 +104,6 @@ my $comma_rule = qr{ \s* [,] }xms;
 my $count_rule = qr{ \s* ( [^,)]+ ) }xms;
 my $close_rule = qr{ \s* [,]? \s* ( [^)]* ) [)] }xms;
 
-my $start_rule = qr{
-    \b
-    (?:
-        # Gettext::Loc, Gettext
-        N? (?: loc_ | __ ) d? c? n? p? x?
-        # BabelFish::Loc
-        | N? loc_b p?
-        # Maketext
-        | l
-    )
-    \s*
-    [(]
-}xms;
-
 my $rules = [
     # loc_, __
     [
@@ -411,7 +432,7 @@ my $rules = [
         'end',
     ],
 
-    # babelfish loc_b
+    # loc_b... (BabelFish)
     'or',
     [
         'begin',
@@ -423,7 +444,6 @@ my $rules = [
         'end',
     ],
     'or',
-    # babelfish loc_bp
     [
         'begin',
         qr{ \b N? loc_b ( p ) \s* [(] }xms,
@@ -437,8 +457,111 @@ my $rules = [
         $close_rule,
         'end',
     ],
+    'or',
+    [
+        'begin',
+        qr{ \b N? loc_b ( d ) \s* [(] }xms,
+        'and',
+        $domain_rule,
+        'and',
+        $comma_rule,
+        'and',
+        $text_rule,
+        'and',
+        $close_rule,
+        'end',
+    ],
+    'or',
+    [
+        'begin',
+        qr{ \b N? loc_b ( dp ) \s* [(] }xms,
+        'and',
+        $domain_rule,
+        'and',
+        $comma_rule,
+        'and',
+        $context_rule,
+        'and',
+        $comma_rule,
+        'and',
+        $text_rule,
+        'and',
+        $close_rule,
+        'end',
+    ],
+    'or',
+    [
+        'begin',
+        qr{ \b N? loc_b ( c ) \s* [(] }xms,
+        'and',
+        $text_rule,
+        'and',
+        $comma_rule,
+        'and',
+        $category_rule,
+        'and',
+        $close_rule,
+        'end',
+    ],
+    'or',
+    [
+        'begin',
+        qr{ \b N? loc_b ( cp ) \s* [(] }xms,
+        'and',
+        $context_rule,
+        'and',
+        $comma_rule,
+        'and',
+        $text_rule,
+        'and',
+        $comma_rule,
+        'and',
+        $category_rule,
+        'and',
+        $close_rule,
+        'end',
+    ],
+    'or',
+    [
+        'begin',
+        qr{ \b N? loc_b ( dc ) \s* [(] }xms,
+        'and',
+        $domain_rule,
+        'and',
+        $comma_rule,
+        'and',
+        $text_rule,
+        'and',
+        $comma_rule,
+        'and',
+        $category_rule,
+        'and',
+        $close_rule,
+        'end',
+    ],
+    'or',
+    [
+        'begin',
+        qr{ \b N? loc_b ( dcp ) \s* [(] }xms,
+        $domain_rule,
+        'and',
+        $comma_rule,
+        'and',
+        $context_rule,
+        'and',
+        $comma_rule,
+        'and',
+        $text_rule,
+        'and',
+        $comma_rule,
+        'and',
+        $category_rule,
+        'and',
+        $close_rule,
+        'end',
+    ],
 
-    # l (maketext)
+    # l (Maketext)
     'or',
     [
         'begin',
@@ -610,7 +733,7 @@ sub stack_item_mapping {
 sub extract {
     my $self = shift;
 
-    $self->start_rule($start_rule);
+    $self->start_rule( $self->_filtered_start_rule );
     $self->rules($rules);
     $self->preprocess;
     $self->SUPER::extract;
@@ -637,7 +760,7 @@ $HeadURL: svn+ssh://steffenw@svn.code.sf.net/p/perl-gettext-oo/code/extract/trun
 
 =head1 VERSION
 
-2.007
+2.010
 
 =head1 DESCRIPTION
 
@@ -645,6 +768,7 @@ This module extracts internationalization data from Template code.
 
 Implemented rules:
 
+ # Gettext::Loc
  loc_('...
  loc_x('...
  loc_n('...
@@ -654,6 +778,7 @@ Implemented rules:
  loc_np('...
  loc_npx('...
 
+ # Gettext::Loc::DomainAndCategory
  loc_d('...
  loc_dx('...
  loc_dn('...
@@ -681,6 +806,7 @@ Implemented rules:
  loc_dcnp('...
  loc_dcnpx('...
 
+ # Gettext
  __('...
  __x('...
  __n('...
@@ -690,6 +816,7 @@ Implemented rules:
  __np('...
  __npx('...
 
+ # Gettext::DomainAndCategory
  __d('...
  __dx('...
  __dn('...
@@ -717,9 +844,21 @@ Implemented rules:
  __dcnp('...
  __dcnpx('...
 
+ # BabelFish
  loc_b('...
  loc_bp('...
 
+ # BabelFish::DomainAndCategory
+ loc_bd('...
+ loc_bdp('...
+
+ loc_bc('...
+ loc_bcp('...
+
+ loc_bdc('...
+ loc_bdcp('...
+
+ # Maketext
  l('...
 
 N before loc..., __... and maketext... is allowed. E.g. Nloc_ and so on.
@@ -731,7 +870,16 @@ Quote and escape any text like: ' text {placeholder} \\ \' ' or q{ text {placeho
     use Locale::TextDomain::OO::Extract::TT;
     use Path::Tiny qw(path);
 
-    my $extractor = Locale::TextDomain::OO::Extract::TT->new;
+    my $extractor = Locale::TextDomain::OO::Extract::TT->new(
+        # optional filter parameter, the default is ['all'],
+        # the following means:
+        # extract for all plugins but not for Plugin
+        # Locale::TextDomain::OO::Plugin::Maketext
+        filter => [ qw(
+            all
+            !Maketext
+        ) ],
+    );
     for ( @files ) {
         $extractor->clear;
         $extractor->filename($_);            # dir/filename for reference
@@ -751,6 +899,15 @@ See Locale::TextDomain::OO::Extract to replace the defaults.
 
     my $extractor = Locale::TextDomain::OO::Extract::TT->new;
 
+=head2 method filter
+
+Ignore some of 'all' or define what to scan.
+See SYNOPSIS and DESCRIPTION for how and what.
+
+    my $array_ref = $extractor->filter;
+
+    $extractor->filter(['all']); # the default
+
 =head2 method preprocess (called by method extract)
 
 This method removes the POD and all after __END__.
